==> linux-PSVR2_03.00.tar.zip: linux/src/kern_module/mtk_wrapper/mtk_wrapper_edid.h <==
/*
 * Copyright (C) 2020 Sony Interactive Entertainment Inc.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

static u8 s_edid_sie_vrh[] = {
#ifdef SUPPORT_HDR
	// VESA block
	0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00,
	0x4D, 0xD9, 0x05, 0xA2, 0x00, 0x00, 0x00, 0x00,
	0x01, 0x1D, 0x01, 0x04, 0xB5, 0x61, 0x00, 0x78,
	0x0A, 0x3D, 0xA5, 0xA9, 0x56, 0x3D, 0xB6, 0x22,
	0x0C, 0x50, 0x54, 0x20, 0x00, 0x00, 0x01, 0x01,
	0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
	0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x08, 0xE8,
	0xA0, 0xF4, 0xF1, 0xF8, 0xA0, 0x70, 0x58, 0x2C,
	0x8A, 0x00, 0x90, 0xCC, 0x10, 0x00, 0x00, 0x1E,
	0x02, 0x3A, 0x80, 0x18, 0x71, 0x38, 0x2D, 0x40,
	0x58, 0x2C, 0x45, 0x00, 0x20, 0xC2, 0x31, 0x00,
	0x00, 0x1E, 0x00, 0x00, 0x00, 0xFC, 0x00, 0x53,
	0x49, 0x45, 0x20, 0x20, 0x56, 0x52, 0x48, 0x0A,
	0x20, 0x20, 0x20, 0x20, 0x00, 0x00, 0x00, 0xFD,
	0x08, 0x38, 0x78, 0x1E, 0x19, 0x78, 0x00, 0x0A,
	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x02, 0xE8,
	// CTA block
	0x02, 0x03, 0x18, 0xE1, 0x44, 0x10, 0x3F, 0x20,
	0x01, 0x23, 0x09, 0x07, 0x07, 0xE2, 0x00, 0x6A,
	0xE3, 0x06, 0x0D, 0x01, 0xE3, 0x05, 0xC0, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x29,
	// Display ID block
	0x12, 0x2B, 0x00, 0x00, 0x03, 0x00, 0x28, 0x98,
	0xCF, 0x01, 0x84, 0x9F, 0x0F, 0xF3, 0x01, 0x57,
	0x80, 0x2B, 0x00, 0xF7, 0x07, 0x9F, 0x00, 0x07,
	0x80, 0x09, 0x00, 0xB2, 0x5B, 0x01, 0x04, 0x9F,
	0x0F, 0xF3, 0x01, 0x57, 0x80, 0x2B, 0x00, 0xF7,
	0x07, 0x9F, 0x00, 0x07, 0x80, 0x09, 0x00, 0xF8,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
#elif defined(CONFIG_MTK_WRAPPER_FACTORY) || defined(CONFIG_MTK_WRAPPER_GAZE_DEBUG) || defined(CONFIG_MTK_WRAPPER_DEBUG)
	// VESA block
	0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00,
	0x4D, 0xD9, 0x05, 0xA2, 0x00, 0x00, 0x00, 0x00,
	0x19, 0x20, 0x01, 0x04, 0xB5, 0x61, 0x00, 0x78,
	0x0A, 0x39, 0x31, 0xAD, 0x52, 0x38, 0xBA, 0x23,
	0x0B, 0x50, 0x54, 0x20, 0x00, 0x00, 0x01, 0x01,
	0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
	0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x08, 0xE8,
	0xA0, 0xF4, 0xF1, 0xF8, 0xA0, 0x70, 0x58, 0x2C,
	0x8A, 0x00, 0x90, 0xCC, 0x10, 0x00, 0x00, 0x1E,
	0x02, 0x3A, 0x80, 0x18, 0x71, 0x38, 0x2D, 0x40,
	0x58, 0x2C, 0x45, 0x00, 0x20, 0xC2, 0x31, 0x00,
	0x00, 0x1E, 0x00, 0x00, 0x00, 0xFC, 0x00, 0x53,
	0x49, 0x45, 0x20, 0x20, 0x56, 0x52, 0x48, 0x0A,
	0x20, 0x20, 0x20, 0x20, 0x00, 0x00, 0x00, 0xFD,
	0x08, 0x38, 0x78, 0x1E, 0x19, 0x78, 0x00, 0x0A,
	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x02, 0x46,
	// CTA block
	0x02, 0x03, 0x11, 0xC0, 0x45, 0x10, 0x3F, 0x20,
	0x01, 0x1F, 0x23, 0x09, 0x07, 0x07, 0xE2, 0x00,
	0x6A, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xD0,
	// Display ID block
	0x70, 0x12, 0x2B, 0x00, 0x00, 0x03, 0x00, 0x28,
	0x98, 0xCF, 0x01, 0x84, 0x9F, 0x0F, 0xF3, 0x01,
	0x57, 0x80, 0x2B, 0x00, 0xF7, 0x07, 0x9F, 0x00,
	0x07, 0x80, 0x09, 0x00, 0xB2, 0x5B, 0x01, 0x04,
	0x9F, 0x0F, 0xF3, 0x01, 0x57, 0x80, 0x2B, 0x00,
	0xF7, 0x07, 0x9F, 0x00, 0x07, 0x80, 0x09, 0x00,
	0xF8, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x90,
#else
	// VESA block
	0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00,
	0x4D, 0xD9, 0x05, 0xA2, 0x00, 0x00, 0x00, 0x00,
	0x19, 0x20, 0x01, 0x04, 0xB5, 0x4F, 0x00, 0x78,
	0x00, 0x39, 0x31, 0xAD, 0x52, 0x38, 0xBA, 0x23,
	0x0B, 0x50, 0x54, 0x20, 0x00, 0x00, 0x01, 0x01,
	0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
	0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x02, 0x3A,
	0x80, 0x18, 0x71, 0x38, 0x2D, 0x40, 0x58, 0x2C,
	0x45, 0x00, 0x20, 0xC2, 0x31, 0x00, 0x00, 0x1E,
	0x1A, 0x36, 0x80, 0xA0, 0x70, 0x38, 0x1F, 0x40,
	0x30, 0x20, 0x35, 0x00, 0x20, 0xC2, 0x31, 0x00,
	0x00, 0x1A, 0x00, 0x00, 0x00, 0xFC, 0x00, 0x53,
	0x49, 0x45, 0x20, 0x20, 0x56, 0x52, 0x48, 0x0A,
	0x20, 0x20, 0x20, 0x20, 0x00, 0x00, 0x00, 0xFD,
	0x00, 0x38, 0x78, 0x1E, 0x8C, 0x1E, 0x00, 0x0A,
	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x01, 0x3E,
	// CTA block
	0x02, 0x03, 0x11, 0xC0, 0x45, 0x10, 0x3F, 0x1F,
	0x20, 0x01, 0x23, 0x09, 0x07, 0x07, 0xE2, 0x00,
	0x6A, 0x04, 0x74, 0x80, 0x18, 0x71, 0x38, 0x2D,
	0x40, 0x58, 0x2C, 0x45, 0x00, 0x20, 0xC2, 0x31,
	0x00, 0x00, 0x1E, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xB0,
#endif
};

==> linux-PSVR2_05.00.tar.zip: linux/src/kern_module/mtk_wrapper/mtk_wrapper_edid.h <==
/*
 * Copyright (C) 2020 Sony Interactive Entertainment Inc.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
static u8 s_edid_sie_vrh[] = {
#if defined(CONFIG_MTK_WRAPPER_FACTORY) || defined(CONFIG_MTK_WRAPPER_GAZE_DEBUG)
    /* VESA block */
	0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00,
	0x4D, 0xD9, 0x05, 0xA2, 0x00, 0x00, 0x00, 0x00,
	0x19, 0x20, 0x01, 0x04, 0xB5, 0x61, 0x00, 0x78,
	0x0A, 0x39, 0x31, 0xAD, 0x52, 0x38, 0xBA, 0x23,
	0x0B, 0x50, 0x54, 0x20, 0x00, 0x00, 0x01, 0x01,
	0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
	0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x08, 0xE8,
	0xA0, 0xF4, 0xF1, 0xF8, 0xA0, 0x70, 0x58, 0x2C,
	0x8A, 0x00, 0x90, 0xCC, 0x10, 0x00, 0x00, 0x1E,
	0x02, 0x3A, 0x80, 0x18, 0x71, 0x38, 0x2D, 0x40,
	0x58, 0x2C, 0x45, 0x00, 0x20, 0xC2, 0x31, 0x00,
	0x00, 0x1E, 0x00, 0x00, 0x00, 0xFC, 0x00, 0x53,
	0x49, 0x45, 0x20, 0x20, 0x56, 0x52, 0x48, 0x0A,
	0x20, 0x20, 0x20, 0x20, 0x00, 0x00, 0x00, 0xFD,
	0x08, 0x38, 0x78, 0x1E, 0x19, 0x78, 0x00, 0x0A,
	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x02, 0x46,
	/* CTA block */
	0x02, 0x03, 0x11, 0xC0, 0x45, 0x10, 0x3F, 0x20,
	0x01, 0x1F, 0x23, 0x09, 0x07, 0x07, 0xE2, 0x00,
	0x6A, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xD0,
	/* Display ID block */
	0x70, 0x12, 0x2B, 0x00, 0x00, 0x03, 0x00, 0x28,
	0x98, 0xCF, 0x01, 0x84, 0x9F, 0x0F, 0xF3, 0x01,
	0x57, 0x80, 0x2B, 0x00, 0xF7, 0x07, 0x9F, 0x00,
	0x07, 0x80, 0x09, 0x00, 0xB2, 0x5B, 0x01, 0x04,
	0x9F, 0x0F, 0xF3, 0x01, 0x57, 0x80, 0x2B, 0x00,
	0xF7, 0x07, 0x9F, 0x00, 0x07, 0x80, 0x09, 0x00,
	0xF8, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x90,
#elif defined(CONFIG_MTK_WRAPPER_DISABLE_4K_DSC)
	// VESA block
	0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00,
	0x4D, 0xD9, 0x05, 0xA2, 0x00, 0x00, 0x00, 0x00,
	0x19, 0x20, 0x01, 0x04, 0xB5, 0x4F, 0x00, 0x78,
	0x00, 0x39, 0x31, 0xAD, 0x52, 0x38, 0xBA, 0x23,
	0x0B, 0x50, 0x54, 0x20, 0x00, 0x00, 0x01, 0x01,
	0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
	0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x02, 0x3A,
	0x80, 0x18, 0x71, 0x38, 0x2D, 0x40, 0x58, 0x2C,
	0x45, 0x00, 0x20, 0xC2, 0x31, 0x00, 0x00, 0x1E,
	0x1A, 0x36, 0x80, 0xA0, 0x70, 0x38, 0x1F, 0x40,
	0x30, 0x20, 0x35, 0x00, 0x20, 0xC2, 0x31, 0x00,
	0x00, 0x1A, 0x00, 0x00, 0x00, 0xFC, 0x00, 0x53,
	0x49, 0x45, 0x20, 0x20, 0x56, 0x52, 0x48, 0x0A,
	0x20, 0x20, 0x20, 0x20, 0x00, 0x00, 0x00, 0xFD,
	0x00, 0x38, 0x78, 0x1E, 0x8C, 0x1E, 0x00, 0x0A,
	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x01, 0x3E,
	// CTA block
	0x02, 0x03, 0x11, 0xC0, 0x45, 0x10, 0x3F, 0x1F,
	0x20, 0x01, 0x23, 0x09, 0x07, 0x07, 0xE2, 0x00,
	0x6A, 0x04, 0x74, 0x80, 0x18, 0x71, 0x38, 0x2D,
	0x40, 0x58, 0x2C, 0x45, 0x00, 0x20, 0xC2, 0x31,
	0x00, 0x00, 0x1E, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xB0,
#else /* defined(CONFIG_MTK_WRAPPER_DEBUG) || defined(CONFIG_MTK_WRAPPER_RELEASE) */
    /* VESA block */
	0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00,
	0x4D, 0xD9, 0x07, 0xC2, 0x00, 0x00, 0x00, 0x00,
	0x19, 0x20, 0x01, 0x04, 0xB5, 0x4F, 0x00, 0x78,
	0x00, 0x39, 0x31, 0xAD, 0x52, 0x38, 0xBA, 0x23,
	0x0B, 0x50, 0x54, 0x00, 0x00, 0x00, 0x01, 0x01,
	0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
	0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x02, 0x3A,
	0x80, 0x18, 0x71, 0x38, 0x2D, 0x40, 0x58, 0x2C,
	0x45, 0x00, 0x20, 0xC2, 0x31, 0x00, 0x00, 0x1E,
	0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0xFC, 0x00, 0x50,
	0x53, 0x20, 0x56, 0x52, 0x32, 0x0A, 0x20, 0x20,
	0x20, 0x20, 0x20, 0x20, 0x00, 0x00, 0x00, 0xFD,
	0x08, 0x18, 0x78, 0x14, 0x0C, 0x77, 0x00, 0x0A,
	0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x02, 0xD1,
	/* CTA block */
	0x02, 0x03, 0x26, 0x80, 0x44, 0x10, 0x3F, 0x20,
	0x1F, 0x23, 0x09, 0x04, 0x07, 0x75, 0x5C, 0x12,
	0xCA, 0x02, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0xE2, 0x00, 0x2A, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x8A,
	/* Display ID block */
	0x70, 0x12, 0x2B, 0x00, 0x00, 0x03, 0x00, 0x28,
	0x98, 0xCF, 0x01, 0x84, 0x9F, 0x0F, 0xF3, 0x01,
	0x57, 0x80, 0x2B, 0x00, 0xF7, 0x07, 0x9F, 0x00,
	0x07, 0x80, 0x09, 0x00, 0xB2, 0x5B, 0x01, 0x04,
	0x9F, 0x0F, 0xF3, 0x01, 0x57, 0x80, 0x2B, 0x00,
	0xF7, 0x07, 0x9F, 0x00, 0x07, 0x80, 0x09, 0x00,
	0xF8, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x90,
#endif
};
